@@ -102,9 +102,9 @@ def test_obj(base_url, browser, browser_version, os_version, os_name, remote_fla
 
 
 @pytest.fixture
-def test_mobile_obj(mobile_os_name, mobile_os_version, device_name, app_package, app_activity, remote_flag, device_flag,
-                    testrail_flag, tesults_flag, test_run_id, app_name, app_path, appium_version, test_env,
-                    interactivemode_flag, product, screenshot_option, no_reset_flag):
+def test_mobile_obj(mobile_os_name, mobile_os_version, device_name, app_package, app_activity, remote_flag, device_flag, testname,
+                    testrail_flag, tesults_flag, test_run_id, app_name, app_path, appium_version, test_env, reportportal_service,
+                    interactivemode_flag, product, xlsx_config, screenshot_option, no_reset_flag):
     """Return an instance of Base Page that knows about the third party integrations
     Need to install appium with npm first: npm install -g appium"""
     try:
@@ -113,18 +113,18 @@ def test_mobile_obj(mobile_os_name, mobile_os_version, device_name, app_package,
         #     mobile_os_name, mobile_os_version, device_name, app_package, app_activity, remote_flag, device_flag, testrail_flag, tesults_flag, app_name, app_path = interactive_mode.ask_questions_mobile(
         #         mobile_os_name, mobile_os_version, device_name, app_package, app_activity, remote_flag, device_flag,
         #         testrail_flag, tesults_flag, app_name, app_path)
-        test_mobile_obj = Mobile_Zero_Page(product=product_list.PatientPortal)
+        test_mobile_obj = Mobile_Zero_Page(product=product)
         test_mobile_obj.test_env = test_env
         test_mobile_obj.screenshot = screenshot_option
+        test_mobile_obj.set_calling_module(testname)
 
-        # Setup Appium Server
-        test_mobile_obj.start_appium()
-
+        test_mobile_obj.xlsx_config = xlsx_config
         # Setup and register a driver
         test_mobile_obj.register_driver(mobile_os_name, mobile_os_version, device_name, app_package, app_activity,
                                         remote_flag, device_flag, app_name, app_path, ud_id, org_id, signing_id,
                                         no_reset_flag, appium_version)
-
+        # Setup Appium Server
+        test_mobile_obj.start_appium()
         # # 3. Setup TestRail reporting
         # if testrail_flag.lower() == 'y':
         #     if test_run_id is None:
@@ -137,12 +137,14 @@ def test_mobile_obj(mobile_os_name, mobile_os_version, device_name, app_package,
         #
         # if tesults_flag.lower() == 'y':
         #     test_mobile_obj.register_tesults()
+        if reportportal_service:
+            test_mobile_obj.set_rp_logger(reportportal_service)
         test_mobile_obj.start_time = int(time.time())
 
         yield test_mobile_obj
 
         # Teardown
-
+        test_mobile_obj.log_obj.remove_logger()  # Remove original log handlers
         test_mobile_obj.wait(3)
         test_mobile_obj.teardown()
 
